@@ -8,45 +8,15 @@ RSpec.describe "bundle install from an existing gemspec" do
     end
   end
 
-  let(:x64_mingw_archs) do
-    if RUBY_PLATFORM == "x64-mingw-ucrt"
-      if Gem.rubygems_version >= Gem::Version.new("3.2.28")
-        ["x64-mingw-ucrt", "x64-mingw32"]
-      else
-        ["x64-mingw32", "x64-unknown"]
-      end
-    else
-      ["x64-mingw32"]
-    end
-  end
-
-  let(:x64_mingw_gems) do
-    x64_mingw_archs.map {|p| "platform_specific (1.0-#{p})" }.join("\n    ")
-  end
-
-  let(:x64_mingw_platforms) do
-    x64_mingw_archs.join("\n  ")
-  end
-
-  def x64_mingw_checksums(checksums)
-    x64_mingw_archs.each do |arch|
-      if arch == "x64-mingw-ucrt"
-        checksums.no_checksum "platform_specific", "1.0", arch
-      else
-        checksums.checksum gem_repo2, "platform_specific", "1.0", arch
-      end
-    end
-  end
-
   it "should install runtime and development dependencies" do
-    build_lib("foo", path: tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.write("Gemfile", "source :rubygems\ngemspec")
       s.add_dependency "bar", "=1.0.0"
       s.add_development_dependency "bar-dev", "=1.0.0"
     end
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo2)}"
-      gemspec :path => '#{tmp.join("foo")}'
+      source "https://gem.repo2"
+      gemspec :path => '#{tmp("foo")}'
     G
 
     expect(the_bundle).to include_gems "bar 1.0.0"
@@ -54,16 +24,16 @@ RSpec.describe "bundle install from an existing gemspec" do
   end
 
   it "that is hidden should install runtime and development dependencies" do
-    build_lib("foo", path: tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.write("Gemfile", "source :rubygems\ngemspec")
       s.add_dependency "bar", "=1.0.0"
       s.add_development_dependency "bar-dev", "=1.0.0"
     end
-    FileUtils.mv tmp.join("foo", "foo.gemspec"), tmp.join("foo", ".gemspec")
+    FileUtils.mv tmp("foo", "foo.gemspec"), tmp("foo", ".gemspec")
 
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo2)}"
-      gemspec :path => '#{tmp.join("foo")}'
+      source "https://gem.repo2"
+      gemspec :path => '#{tmp("foo")}'
     G
 
     expect(the_bundle).to include_gems "bar 1.0.0"
@@ -76,50 +46,50 @@ RSpec.describe "bundle install from an existing gemspec" do
       build_gem "baz", "1.1"
     end
 
-    build_lib("foo", path: tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.write("Gemfile", "source :rubygems\ngemspec")
       s.add_dependency "baz", ">= 1.0", "< 1.1"
     end
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo2)}"
-      gemspec :path => '#{tmp.join("foo")}'
+      source "https://gem.repo2"
+      gemspec :path => '#{tmp("foo")}'
     G
 
     expect(the_bundle).to include_gems "baz 1.0"
   end
 
   it "should raise if there are no gemspecs available" do
-    build_lib("foo", path: tmp.join("foo"), gemspec: false)
+    build_lib("foo", path: tmp("foo"), gemspec: false)
 
     install_gemfile <<-G, raise_on_error: false
-      source "#{file_uri_for(gem_repo2)}"
-      gemspec :path => '#{tmp.join("foo")}'
+      source "https://gem.repo2"
+      gemspec :path => '#{tmp("foo")}'
     G
-    expect(err).to match(/There are no gemspecs at #{tmp.join("foo")}/)
+    expect(err).to match(/There are no gemspecs at #{tmp("foo")}/)
   end
 
   it "should raise if there are too many gemspecs available" do
-    build_lib("foo", path: tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.write("foo2.gemspec", build_spec("foo", "4.0").first.to_ruby)
     end
 
     install_gemfile <<-G, raise_on_error: false
-      source "#{file_uri_for(gem_repo2)}"
-      gemspec :path => '#{tmp.join("foo")}'
+      source "https://gem.repo2"
+      gemspec :path => '#{tmp("foo")}'
     G
-    expect(err).to match(/There are multiple gemspecs at #{tmp.join("foo")}/)
+    expect(err).to match(/There are multiple gemspecs at #{tmp("foo")}/)
   end
 
   it "should pick a specific gemspec" do
-    build_lib("foo", path: tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.write("foo2.gemspec", "")
       s.add_dependency "bar", "=1.0.0"
       s.add_development_dependency "bar-dev", "=1.0.0"
     end
 
     install_gemfile(<<-G)
-      source "#{file_uri_for(gem_repo2)}"
-      gemspec :path => '#{tmp.join("foo")}', :name => 'foo'
+      source "https://gem.repo2"
+      gemspec :path => '#{tmp("foo")}', :name => 'foo'
     G
 
     expect(the_bundle).to include_gems "bar 1.0.0"
@@ -127,15 +97,15 @@ RSpec.describe "bundle install from an existing gemspec" do
   end
 
   it "should use a specific group for development dependencies" do
-    build_lib("foo", path: tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.write("foo2.gemspec", "")
       s.add_dependency "bar", "=1.0.0"
       s.add_development_dependency "bar-dev", "=1.0.0"
     end
 
     install_gemfile(<<-G)
-      source "#{file_uri_for(gem_repo2)}"
-      gemspec :path => '#{tmp.join("foo")}', :name => 'foo', :development_group => :dev
+      source "https://gem.repo2"
+      gemspec :path => '#{tmp("foo")}', :name => 'foo', :development_group => :dev
     G
 
     expect(the_bundle).to include_gems "bar 1.0.0"
@@ -144,33 +114,33 @@ RSpec.describe "bundle install from an existing gemspec" do
   end
 
   it "should match a lockfile even if the gemspec defines development dependencies" do
-    build_lib("foo", path: tmp.join("foo")) do |s|
-      s.write("Gemfile", "source '#{file_uri_for(gem_repo1)}'\ngemspec")
+    build_lib("foo", path: tmp("foo")) do |s|
+      s.write("Gemfile", "source 'https://gem.repo1'\ngemspec")
       s.add_dependency "actionpack", "=2.3.2"
       s.add_development_dependency "rake", rake_version
     end
 
-    bundle "install", dir: tmp.join("foo")
+    bundle "install", dir: tmp("foo"), artifice: "compact_index", env: { "BUNDLER_SPEC_GEM_REPO" => gem_repo1.to_s }
     # This should really be able to rely on $stderr, but, it's not written
     # right, so we can't. In fact, this is a bug negation test, and so it'll
     # ghost pass in future, and will only catch a regression if the message
     # doesn't change. Exit codes should be used correctly (they can be more
     # than just 0 and 1).
     bundle "config set --local deployment true"
-    output = bundle("install", dir: tmp.join("foo"))
+    output = bundle("install", dir: tmp("foo"), artifice: "compact_index", env: { "BUNDLER_SPEC_GEM_REPO" => gem_repo1.to_s })
     expect(output).not_to match(/You have added to the Gemfile/)
     expect(output).not_to match(/You have deleted from the Gemfile/)
     expect(output).not_to match(/the lockfile can't be updated because frozen mode is set/)
   end
 
   it "should match a lockfile without needing to re-resolve" do
-    build_lib("foo", path: tmp.join("foo")) do |s|
-      s.add_dependency "rack"
+    build_lib("foo", path: tmp("foo")) do |s|
+      s.add_dependency "myrack"
     end
 
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo1)}"
-      gemspec :path => '#{tmp.join("foo")}'
+      source "https://gem.repo1"
+      gemspec :path => '#{tmp("foo")}'
     G
 
     bundle "install", verbose: true
@@ -180,47 +150,47 @@ RSpec.describe "bundle install from an existing gemspec" do
   end
 
   it "should match a lockfile without needing to re-resolve with development dependencies" do
-    simulate_platform java
+    simulate_platform "java" do
+      build_lib("foo", path: tmp("foo")) do |s|
+        s.add_dependency "myrack"
+        s.add_development_dependency "thin"
+      end
 
-    build_lib("foo", path: tmp.join("foo")) do |s|
-      s.add_dependency "rack"
-      s.add_development_dependency "thin"
+      install_gemfile <<-G
+        source "https://gem.repo1"
+        gemspec :path => '#{tmp("foo")}'
+      G
+
+      bundle "install", verbose: true
+
+      message = "Found no changes, using resolution from the lockfile"
+      expect(out.scan(message).size).to eq(1)
     end
-
-    install_gemfile <<-G
-      source "#{file_uri_for(gem_repo1)}"
-      gemspec :path => '#{tmp.join("foo")}'
-    G
-
-    bundle "install", verbose: true
-
-    message = "Found no changes, using resolution from the lockfile"
-    expect(out.scan(message).size).to eq(1)
   end
 
   it "should match a lockfile on non-ruby platforms with a transitive platform dependency", :jruby_only do
-    build_lib("foo", path: tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.add_dependency "platform_specific"
     end
 
     system_gems "platform_specific-1.0-java", path: default_bundle_path
 
     install_gemfile <<-G
-      gemspec :path => '#{tmp.join("foo")}'
+      gemspec :path => '#{tmp("foo")}'
     G
 
     bundle "update --bundler", artifice: "compact_index", verbose: true
-    expect(the_bundle).to include_gems "foo 1.0", "platform_specific 1.0 JAVA"
+    expect(the_bundle).to include_gems "foo 1.0", "platform_specific 1.0 java"
   end
 
   it "should evaluate the gemspec in its directory" do
-    build_lib("foo", path: tmp.join("foo"))
-    File.open(tmp.join("foo/foo.gemspec"), "w") do |s|
-      s.write "raise 'ahh' unless Dir.pwd == '#{tmp.join("foo")}'"
+    build_lib("foo", path: tmp("foo"))
+    File.open(tmp("foo/foo.gemspec"), "w") do |s|
+      s.write "raise 'ahh' unless Dir.pwd == '#{tmp("foo")}'"
     end
 
     install_gemfile <<-G, raise_on_error: false
-      gemspec :path => '#{tmp.join("foo")}'
+      gemspec :path => '#{tmp("foo")}'
     G
     expect(last_command.stdboth).not_to include("ahh")
   end
@@ -231,16 +201,16 @@ RSpec.describe "bundle install from an existing gemspec" do
     #
     # issue was caused by rubygems having an unresolved gem during a require,
     # so emulate that
-    system_gems %w[rack-1.0.0 rack-0.9.1 rack-obama-1.0]
+    system_gems %w[myrack-1.0.0 myrack-0.9.1 myrack-obama-1.0]
 
     build_lib("foo", path: bundled_app)
     gemspec = bundled_app("foo.gemspec").read
     bundled_app("foo.gemspec").open("w") do |f|
-      f.write "#{gemspec.strip}.tap { gem 'rack-obama'; require 'rack/obama' }"
+      f.write "#{gemspec.strip}.tap { gem 'myrack-obama'; require 'myrack/obama' }"
     end
 
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo1)}"
+      source "https://gem.repo1"
       gemspec
     G
 
@@ -248,7 +218,7 @@ RSpec.describe "bundle install from an existing gemspec" do
   end
 
   it "allows conflicts" do
-    build_lib("foo", path: tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.version = "1.0.0"
       s.add_dependency "bar", "= 1.0.0"
     end
@@ -258,16 +228,16 @@ RSpec.describe "bundle install from an existing gemspec" do
     build_gem "foo", "0.0.1", to_bundle: true
 
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo2)}"
+      source "https://gem.repo2"
       gem "deps"
-      gemspec :path => '#{tmp.join("foo")}', :name => 'foo'
+      gemspec :path => '#{tmp("foo")}', :name => 'foo'
     G
 
     expect(the_bundle).to include_gems "foo 1.0.0"
   end
 
   it "does not break Gem.finish_resolve with conflicts" do
-    build_lib("foo", path: tmp.join("foo")) do |s|
+    build_lib("foo", path: tmp("foo")) do |s|
       s.version = "1.0.0"
       s.add_dependency "bar", "= 1.0.0"
     end
@@ -279,9 +249,9 @@ RSpec.describe "bundle install from an existing gemspec" do
     end
 
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo2)}"
+      source "https://gem.repo2"
       gem "deps"
-      gemspec :path => '#{tmp.join("foo")}', :name => 'foo'
+      gemspec :path => '#{tmp("foo")}', :name => 'foo'
     G
 
     expect(the_bundle).to include_gems "foo 1.0.0"
@@ -294,7 +264,7 @@ RSpec.describe "bundle install from an existing gemspec" do
     build_lib "omg", "2.0", path: lib_path("omg")
 
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo1)}"
+      source "https://gem.repo1"
       gemspec :path => "#{lib_path("omg")}"
     G
 
@@ -313,7 +283,7 @@ RSpec.describe "bundle install from an existing gemspec" do
         end
 
         install_gemfile <<-G
-          source "#{file_uri_for(gem_repo1)}"
+          source "https://gem.repo1"
           gemspec
         G
 
@@ -335,23 +305,23 @@ RSpec.describe "bundle install from an existing gemspec" do
     before do
       # build the "parent" gem that depends on another gem in the same repo
       build_lib "source_conflict", path: bundled_app do |s|
-        s.add_dependency "rack_middleware"
+        s.add_dependency "myrack_middleware"
       end
 
       # build the "child" gem that is the same version as a released gem, but
       # has completely different and conflicting dependency requirements
-      build_lib "rack_middleware", "1.0", path: bundled_app("rack_middleware") do |s|
-        s.add_dependency "rack", "1.0" # anything other than 0.9.1
+      build_lib "myrack_middleware", "1.0", path: bundled_app("myrack_middleware") do |s|
+        s.add_dependency "myrack", "1.0" # anything other than 0.9.1
       end
     end
 
     it "should install the child gemspec's deps" do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gemspec
       G
 
-      expect(the_bundle).to include_gems "rack 1.0"
+      expect(the_bundle).to include_gems "myrack 1.0"
     end
   end
 
@@ -359,8 +329,8 @@ RSpec.describe "bundle install from an existing gemspec" do
     let(:source_uri) { "http://localgemserver.test" }
 
     before do
-      build_lib("foo", path: tmp.join("foo")) do |s|
-        s.add_dependency "rack", "=1.0.0"
+      build_lib("foo", path: tmp("foo")) do |s|
+        s.add_dependency "myrack", "=1.0.0"
       end
 
       gemfile <<-G
@@ -368,7 +338,7 @@ RSpec.describe "bundle install from an existing gemspec" do
         gemspec :path => "../foo"
       G
 
-      checksums = checksums_section_when_existing do |c|
+      checksums = checksums_section_when_enabled do |c|
         c.no_checksum "foo", "1.0"
       end
 
@@ -377,15 +347,15 @@ RSpec.describe "bundle install from an existing gemspec" do
           remote: ../foo
           specs:
             foo (1.0)
-              rack (= 1.0.0)
+              myrack (= 1.0.0)
 
         GEM
           remote: #{source_uri}
           specs:
-            rack (1.0.0)
+            myrack (1.0.0)
 
         PLATFORMS
-          #{generic_local_platform}
+          ruby
 
         DEPENDENCIES
           foo!
@@ -398,9 +368,9 @@ RSpec.describe "bundle install from an existing gemspec" do
     context "using JRuby with explicit platform", :jruby_only do
       before do
         create_file(
-          tmp.join("foo", "foo-java.gemspec"),
+          tmp("foo", "foo-java.gemspec"),
           build_spec("foo", "1.0", "java") do
-            dep "rack", "=1.0.0"
+            dep "myrack", "=1.0.0"
             @spec.authors = "authors"
             @spec.summary = "summary"
           end.first.to_ruby
@@ -409,15 +379,15 @@ RSpec.describe "bundle install from an existing gemspec" do
 
       it "should install" do
         results = bundle "install", artifice: "endpoint"
-        expect(results).to include("Installing rack 1.0.0")
-        expect(the_bundle).to include_gems "rack 1.0.0"
+        expect(results).to include("Installing myrack 1.0.0")
+        expect(the_bundle).to include_gems "myrack 1.0.0"
       end
     end
 
     it "should install", :jruby do
       results = bundle "install", artifice: "endpoint"
-      expect(results).to include("Installing rack 1.0.0")
-      expect(the_bundle).to include_gems "rack 1.0.0"
+      expect(results).to include("Installing myrack 1.0.0")
+      expect(the_bundle).to include_gems "myrack 1.0.0"
     end
 
     context "bundled for multiple platforms" do
@@ -441,7 +411,7 @@ RSpec.describe "bundle install from an existing gemspec" do
         end
 
         gemfile <<-G
-          source "#{file_uri_for(gem_repo2)}"
+          source "https://gem.repo2"
           gemspec
         G
 
@@ -450,7 +420,8 @@ RSpec.describe "bundle install from an existing gemspec" do
 
         simulate_new_machine
         simulate_platform("jruby") { bundle "install" }
-        simulate_platform(x64_mingw32) { bundle "install" }
+        expect(lockfile).to include("platform_specific (1.0-java)")
+        simulate_platform("x64-mingw32") { bundle "install" }
       end
 
       context "on ruby" do
@@ -461,13 +432,13 @@ RSpec.describe "bundle install from an existing gemspec" do
 
         context "as a runtime dependency" do
           it "keeps all platform dependencies in the lockfile" do
-            expect(the_bundle).to include_gems "foo 1.0", "platform_specific 1.0 RUBY"
+            expect(the_bundle).to include_gems "foo 1.0", "platform_specific 1.0 ruby"
 
-            checksums = checksums_section_when_existing do |c|
+            checksums = checksums_section_when_enabled do |c|
               c.no_checksum "foo", "1.0"
               c.checksum gem_repo2, "platform_specific", "1.0"
               c.checksum gem_repo2, "platform_specific", "1.0", "java"
-              x64_mingw_checksums(c)
+              c.checksum gem_repo2, "platform_specific", "1.0", "x64-mingw32"
             end
 
             expect(lockfile).to eq <<~L
@@ -478,16 +449,16 @@ RSpec.describe "bundle install from an existing gemspec" do
                     platform_specific
 
               GEM
-                remote: #{file_uri_for(gem_repo2)}/
+                remote: https://gem.repo2/
                 specs:
                   platform_specific (1.0)
                   platform_specific (1.0-java)
-                  #{x64_mingw_gems}
+                  platform_specific (1.0-x64-mingw32)
 
               PLATFORMS
                 java
                 ruby
-                #{x64_mingw_platforms}
+                x64-mingw32
 
               DEPENDENCIES
                 foo!
@@ -502,13 +473,13 @@ RSpec.describe "bundle install from an existing gemspec" do
           let(:platform_specific_type) { :development }
 
           it "keeps all platform dependencies in the lockfile" do
-            expect(the_bundle).to include_gems "foo 1.0", "platform_specific 1.0 RUBY"
+            expect(the_bundle).to include_gems "foo 1.0", "platform_specific 1.0 ruby"
 
-            checksums = checksums_section_when_existing do |c|
+            checksums = checksums_section_when_enabled do |c|
               c.no_checksum "foo", "1.0"
               c.checksum gem_repo2, "platform_specific", "1.0"
               c.checksum gem_repo2, "platform_specific", "1.0", "java"
-              x64_mingw_checksums(c)
+              c.checksum gem_repo2, "platform_specific", "1.0", "x64-mingw32"
             end
 
             expect(lockfile).to eq <<~L
@@ -518,16 +489,16 @@ RSpec.describe "bundle install from an existing gemspec" do
                   foo (1.0)
 
               GEM
-                remote: #{file_uri_for(gem_repo2)}/
+                remote: https://gem.repo2/
                 specs:
                   platform_specific (1.0)
                   platform_specific (1.0-java)
-                  #{x64_mingw_gems}
+                  platform_specific (1.0-x64-mingw32)
 
               PLATFORMS
                 java
                 ruby
-                #{x64_mingw_platforms}
+                x64-mingw32
 
               DEPENDENCIES
                 foo!
@@ -544,14 +515,14 @@ RSpec.describe "bundle install from an existing gemspec" do
           let(:dependency) { "indirect_platform_specific" }
 
           it "keeps all platform dependencies in the lockfile" do
-            expect(the_bundle).to include_gems "foo 1.0", "indirect_platform_specific 1.0", "platform_specific 1.0 RUBY"
+            expect(the_bundle).to include_gems "foo 1.0", "indirect_platform_specific 1.0", "platform_specific 1.0 ruby"
 
-            checksums = checksums_section_when_existing do |c|
+            checksums = checksums_section_when_enabled do |c|
               c.no_checksum "foo", "1.0"
               c.checksum gem_repo2, "indirect_platform_specific", "1.0"
               c.checksum gem_repo2, "platform_specific", "1.0"
               c.checksum gem_repo2, "platform_specific", "1.0", "java"
-              x64_mingw_checksums(c)
+              c.checksum gem_repo2, "platform_specific", "1.0", "x64-mingw32"
             end
 
             expect(lockfile).to eq <<~L
@@ -561,18 +532,18 @@ RSpec.describe "bundle install from an existing gemspec" do
                   foo (1.0)
 
               GEM
-                remote: #{file_uri_for(gem_repo2)}/
+                remote: https://gem.repo2/
                 specs:
                   indirect_platform_specific (1.0)
                     platform_specific
                   platform_specific (1.0)
                   platform_specific (1.0-java)
-                  #{x64_mingw_gems}
+                  platform_specific (1.0-x64-mingw32)
 
               PLATFORMS
                 java
                 ruby
-                #{x64_mingw_platforms}
+                x64-mingw32
 
               DEPENDENCIES
                 foo!
@@ -589,10 +560,10 @@ RSpec.describe "bundle install from an existing gemspec" do
 
   context "with multiple platforms" do
     before do
-      build_lib("foo", path: tmp.join("foo")) do |s|
+      build_lib("foo", path: tmp("foo")) do |s|
         s.version = "1.0.0"
-        s.add_development_dependency "rack"
-        s.write "foo-universal-java.gemspec", build_spec("foo", "1.0.0", "universal-java") {|sj| sj.runtime "rack", "1.0.0" }.first.to_ruby
+        s.add_development_dependency "myrack"
+        s.write "foo-universal-java.gemspec", build_spec("foo", "1.0.0", "universal-java") {|sj| sj.runtime "myrack", "1.0.0" }.first.to_ruby
       end
     end
 
@@ -600,11 +571,11 @@ RSpec.describe "bundle install from an existing gemspec" do
       bundle "config set --local force_ruby_platform true"
 
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gemspec :path => '#{tmp.join("foo")}', :name => 'foo'
+        source "https://gem.repo1"
+        gemspec :path => '#{tmp("foo")}', :name => 'foo'
       G
 
-      expect(the_bundle).to include_gems "foo 1.0.0", "rack 1.0.0"
+      expect(the_bundle).to include_gems "foo 1.0.0", "myrack 1.0.0"
     end
 
     it "installs the ruby platform gemspec and skips dev deps with `without development` configured" do
@@ -612,18 +583,18 @@ RSpec.describe "bundle install from an existing gemspec" do
 
       bundle "config set --local without development"
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gemspec :path => '#{tmp.join("foo")}', :name => 'foo'
+        source "https://gem.repo1"
+        gemspec :path => '#{tmp("foo")}', :name => 'foo'
       G
 
       expect(the_bundle).to include_gem "foo 1.0.0"
-      expect(the_bundle).not_to include_gem "rack"
+      expect(the_bundle).not_to include_gem "myrack"
     end
   end
 
   context "with multiple platforms and resolving for more specific platforms" do
     before do
-      build_lib("chef", path: tmp.join("chef")) do |s|
+      build_lib("chef", path: tmp("chef")) do |s|
         s.version = "17.1.17"
         s.write "chef-universal-mingw32.gemspec", build_spec("chef", "17.1.17", "universal-mingw32") {|sw| sw.runtime "win32-api", "~> 1.5.3" }.first.to_ruby
       end
@@ -637,11 +608,11 @@ RSpec.describe "bundle install from an existing gemspec" do
       end
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo4)}"
+        source "https://gem.repo4"
         gemspec :path => "../chef"
       G
 
-      checksums = checksums_section_when_existing do |c|
+      checksums = checksums_section_when_enabled do |c|
         c.no_checksum "chef", "17.1.17"
         c.no_checksum "chef", "17.1.17", "universal-mingw32"
         c.checksum gem_repo4, "win32-api", "1.5.3", "universal-mingw32"
@@ -656,14 +627,12 @@ RSpec.describe "bundle install from an existing gemspec" do
               win32-api (~> 1.5.3)
 
         GEM
-          remote: #{file_uri_for(gem_repo4)}/
+          remote: https://gem.repo4/
           specs:
             win32-api (1.5.3-universal-mingw32)
 
         PLATFORMS
-          ruby
-          #{x64_mingw_platforms}
-          x86-mingw32
+          #{lockfile_platforms("ruby", "x64-mingw32", "x86-mingw32")}
 
         DEPENDENCIES
           chef!
@@ -682,7 +651,7 @@ RSpec.describe "bundle install from an existing gemspec" do
 
   context "with multiple locked platforms" do
     before do
-      build_lib("activeadmin", path: tmp.join("activeadmin")) do |s|
+      build_lib("activeadmin", path: tmp("activeadmin")) do |s|
         s.version = "2.9.0"
         s.add_dependency "railties", ">= 5.2", "< 6.2"
       end
@@ -696,7 +665,7 @@ RSpec.describe "bundle install from an existing gemspec" do
       end
 
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo4)}"
+        source "https://gem.repo4"
         gemspec :path => "../activeadmin"
         gem "jruby-openssl", :platform => :jruby
       G
@@ -705,9 +674,9 @@ RSpec.describe "bundle install from an existing gemspec" do
     end
 
     it "does not remove the platform specific specs from the lockfile when re-resolving due to gemspec changes" do
-      checksums = checksums_section_when_existing do |c|
+      checksums = checksums_section_when_enabled do |c|
         c.no_checksum "activeadmin", "2.9.0"
-        c.no_checksum "jruby-openssl", "0.10.7", "java"
+        c.checksum gem_repo4, "jruby-openssl", "0.10.7", "java"
         c.checksum gem_repo4, "railties", "6.1.4"
       end
 
@@ -719,7 +688,7 @@ RSpec.describe "bundle install from an existing gemspec" do
               railties (>= 5.2, < 6.2)
 
         GEM
-          remote: #{file_uri_for(gem_repo4)}/
+          remote: https://gem.repo4/
           specs:
             jruby-openssl (0.10.7-java)
             railties (6.1.4)
@@ -735,7 +704,7 @@ RSpec.describe "bundle install from an existing gemspec" do
            #{Bundler::VERSION}
       L
 
-      gemspec = tmp.join("activeadmin/activeadmin.gemspec")
+      gemspec = tmp("activeadmin/activeadmin.gemspec")
       File.write(gemspec, File.read(gemspec).sub(">= 5.2", ">= 6.0"))
 
       previous_lockfile = lockfile
